@@ -1,6 +1,6 @@
 use std::{convert::TryFrom, io};
 
-use noodles_bgzf::index::Chunk;
+use noodles_csi::index::reference_sequence::bin::Chunk;
 
 use crate::{record::ReferenceSequenceId, Record};
 
@@ -24,7 +24,8 @@ impl Builder {
     ///
     /// ```
     /// use noodles_bam::{self as bam, bai};
-    /// use noodles_bgzf::{self as bgzf, index::Chunk};
+    /// use noodles_bgzf as bgzf;
+    /// use noodles_csi::index::reference_sequence::bin::Chunk;
     ///
     /// let mut builder = bai::Index::builder();
     ///
@@ -104,6 +105,7 @@ mod tests {
     use std::convert::TryFrom;
 
     use noodles_bgzf as bgzf;
+    use noodles_csi::BinningIndex;
     use noodles_sam::{
         self as sam,
         record::{Flags, Position},
@@ -150,7 +152,7 @@ mod tests {
 
         let index = builder.build(reference_sequences.len());
         assert_eq!(index.reference_sequences().len(), 2);
-        assert_eq!(index.unplaced_unmapped_read_count(), Some(1));
+        assert_eq!(index.unplaced_unmapped_record_count(), Some(1));
 
         Ok(())
     }
